# coding: utf-8
# Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.

SERVICE_ENDPOINTS = {
    "audit": "https://audit.{domain}/20160918",
    "blockstorage": "https://iaas.{domain}/20160918",
    "compute": "https://iaas.{domain}/20160918",
    "virtual_network": "https://iaas.{domain}/20160918",
    "database": "https://database.{domain}/20160918",
    "dns": "https://dns.{domain}/20180115",
    "email": "https://email.{domain}/20170907",
    "file_storage": "https://filestorage.{domain}/20171215",
    "identity": "https://identity.{domain}/20160918",
    "load_balancer": "https://iaas.{domain}/20170115",
    "object_storage": "https://objectstorage.{domain}"
}
